@@ -15,9 +15,9 @@ from datetime import datetime
 _now = datetime.now().strftime("%Y%m%d")
 
 __title__ = 'ut_pac'
-__description__ = 'Package Management Utilities.'
+__description__ = 'Utilities for Package Management.'
 __url__ = 'https://ut-pac.readthedocs.io/en/latest'
-__version__ = f'1.2.0.{_now}'
+__version__ = f'1.3.3.{_now}'
 __build__ = _now
 __author__ = 'Bernd Stroehle'
 __author_email__ = 'bernd.stroehle@gmail.com'
